==> open-cluster-management-cluster-model-6.4.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PlacementDecisionListFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PlacementDecisionListFluent<A extends PlacementDecisionListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,PlacementDecision item);
  public A setToItems(Integer index,PlacementDecision item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementDecision... items);
  public A addAllToItems(Collection<PlacementDecision> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementDecision... items);
  public A removeAllFromItems(Collection<PlacementDecision> items);
  public A removeMatchingFromItems(Predicate<PlacementDecisionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PlacementDecision> getItems();
  public List<PlacementDecision> buildItems();
  public PlacementDecision buildItem(Integer index);
  public PlacementDecision buildFirstItem();
  public PlacementDecision buildLastItem();
  public PlacementDecision buildMatchingItem(Predicate<PlacementDecisionBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PlacementDecisionBuilder> predicate);
  public A withItems(List<PlacementDecision> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementDecision... items);
  public Boolean hasItems();
  public PlacementDecisionListFluent.ItemsNested<A> addNewItem();
  public PlacementDecisionListFluent.ItemsNested<A> addNewItemLike(PlacementDecision item);
  public PlacementDecisionListFluent.ItemsNested<A> setNewItemLike(Integer index,PlacementDecision item);
  public PlacementDecisionListFluent.ItemsNested<A> editItem(Integer index);
  public PlacementDecisionListFluent.ItemsNested<A> editFirstItem();
  public PlacementDecisionListFluent.ItemsNested<A> editLastItem();
  public PlacementDecisionListFluent.ItemsNested<A> editMatchingItem(Predicate<PlacementDecisionBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,PlacementDecisionFluent<PlacementDecisionListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-cluster-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PlacementDecisionListFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PlacementDecisionListFluent<A extends PlacementDecisionListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,PlacementDecision item);
  public A setToItems(int index,PlacementDecision item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementDecision... items);
  public A addAllToItems(Collection<PlacementDecision> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementDecision... items);
  public A removeAllFromItems(Collection<PlacementDecision> items);
  public A removeMatchingFromItems(Predicate<PlacementDecisionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PlacementDecision> getItems();
  public List<PlacementDecision> buildItems();
  public PlacementDecision buildItem(int index);
  public PlacementDecision buildFirstItem();
  public PlacementDecision buildLastItem();
  public PlacementDecision buildMatchingItem(Predicate<PlacementDecisionBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PlacementDecisionBuilder> predicate);
  public A withItems(List<PlacementDecision> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementDecision... items);
  public Boolean hasItems();
  public PlacementDecisionListFluent.ItemsNested<A> addNewItem();
  public PlacementDecisionListFluent.ItemsNested<A> addNewItemLike(PlacementDecision item);
  public PlacementDecisionListFluent.ItemsNested<A> setNewItemLike(int index,PlacementDecision item);
  public PlacementDecisionListFluent.ItemsNested<A> editItem(int index);
  public PlacementDecisionListFluent.ItemsNested<A> editFirstItem();
  public PlacementDecisionListFluent.ItemsNested<A> editLastItem();
  public PlacementDecisionListFluent.ItemsNested<A> editMatchingItem(Predicate<PlacementDecisionBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,PlacementDecisionFluent<PlacementDecisionListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
